import { defineConfig } from "vite";
import vue from '@vitejs/plugin-vue';
import path from 'path';
import dts from 'vite-plugin-dts';
import DefineOptions from "unplugin-vue-define-options/vite";

export default defineConfig({
    build: {
        rollupOptions: {
            external: ['vue', 'vue-grid-layout'],
            output: [
                {
                    format: 'es',
                    entryFileNames: '[name].mjs',
                    preserveModules: true,
                    preserveModulesRoot: path.join(__dirname, ''),
                    exports: 'named',
                    dir: 'dist/es'
                },
                {
                    format: 'cjs',
                    entryFileNames: '[name].js',
                    preserveModules: true,
                    preserveModulesRoot: path.join(__dirname, ''),
                    exports: 'named',
                    dir: 'dist/cjs'
                }
            ]
        },
        lib: {
            entry: path.resolve(__dirname, 'index.ts')
        }
    },
    plugins: [
        vue(),
        dts({
            entryRoot: '.',
            outDir: 'dist/types',
            exclude: ['node_modules', 'dist'],
            tsconfigPath: '../../tsconfig.json',
        }),
        DefineOptions()
    ]
})
